.. _manual:

******************
PyMVPA User Manual
******************

.. toctree::
   :maxdepth: 2

   intro
   installation
   support
   tutorial
   examples
   cmdline
   misc
   faq
   glossary
   changelog
   references
   modref
   legal
